// --- Automatyczny reconnect po powrocie do karty/przywróceniu internetu ---
function reconnectIfNeeded() {
    if (!socket.connected) {
        socket.connect();
    }
}

document.addEventListener("visibilitychange", function() {
    if (!document.hidden) {
        reconnectIfNeeded();
    }
});

window.addEventListener("focus", function() {
    reconnectIfNeeded();
});

window.addEventListener("online", function() {
    reconnectIfNeeded();
});

// --- Blokowanie checkboxów na czas reconnect ---
function disableCheckboxes(disable) {
    document.querySelectorAll('#items input[type="checkbox"]').forEach(cb => {
        cb.disabled = disable;
    });
}

// --- Toasty przy rozłączeniu i połączeniu ---
let firstConnect = true;
let wasReconnected = false; // flaga do kontrolowania toasta

socket.on('connect', function() {
    if (!firstConnect) {
        showToast('Połączono z serwerem! 🔄', 'info');
        disableCheckboxes(true);
        wasReconnected = true; // zaznacz reconnect

        if (window.LIST_ID && window.usernameForReconnect) {
            console.log('Ponownie wysyłam join_list:', window.LIST_ID, window.usernameForReconnect);
            socket.emit('join_list', { room: window.LIST_ID, username: window.usernameForReconnect });
        }
    }
    firstConnect = false;
});

// --- Nasłuch potwierdzenia dołączenia do pokoju ---
socket.off('joined_confirmation');
socket.on('joined_confirmation', function(data) {
    console.log('Potwierdzenie joined:', data.room);
    if (wasReconnected) {
        showToast(`Lista: ${data.list_title} – ponownie dołączono.`, 'info');
        wasReconnected = false;
    }
    disableCheckboxes(false); // odblokuj zawsze
});

socket.on('disconnect', function(reason) {
    showToast('Utracono połączenie z serwerem...', 'warning');
    disableCheckboxes(true);
});
